sqlobject.sybase.sybaseconnection module — SQLObject 3.9.1 documentation

# sqlobject.sybase.sybaseconnection module

class `sqlobject.sybase.sybaseconnection.` `SybaseConnection`(db, user, password='', host='localhost', port=None, locking=1, **kw)

  Bases: `sqlobject.dbconnection.DBAPI`

  `HAS_IDENTITY` = "\n SELECT col.name, col.status, obj.name\n FROM syscolumns col\n JOIN sysobjects obj\n ON obj.id = col.id\n WHERE obj.name = '%s'\n AND (col.status & 0x80) = 0x80\n "
  `NumericType` = None
  `SHOW_COLUMNS` = "SELECT COLUMN_NAME, DATA_TYPE, IS_NULLABLE, COLUMN_DEFAULT FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = '%s'"
  `SHOW_TABLES` = "SELECT name FROM sysobjects WHERE type='U'"
  `addColumn`(tableName, column)
  `columnsFromSchema`(tableName, soClass)
  `createColumn`(soClass, col)
  `createIDColumn`(soClass)
  `createIndexSQL`(soClass, index)
  `createReferenceConstraint`(soClass, col)
  `dbName` = 'sybase'
  `delColumn`(sqlmeta, column)
  `guessClass`(t)
  `insert_id`(conn)

    Sybase adapter/cursor does not support the insert_id method.

  `joinSQLType`(join)
  `makeConnection`()
  `schemes` = ['sybase']
  `supportTransactions` = False
  `tableExists`(tableName)